@@ -148,20 +148,36 @@ def build_image(
     logger.info("Finished building image")
 
 
+def pull_image(image: str) -> None:
+    """
+    Pulls an image from Docker Hub.
+
+    Parameters
+    ----------
+    image : str
+        The name of the image to pull.
+    """
+    logger.info(f"Pulling image {image} from Docker Hub")
+    client = docker.from_env()
+    client.images.pull(image)
+    logger.info("Pulled image")
+
+
 class BuildDockerImageSubcommand(SetupSubcommand):
-    def __init__(
-        self,
-        image: str,
-        root: str,
-    ) -> None:
-        self.image = image
+    def __init__(self, root: str, default_image: str) -> None:
         self.root = root
+        self.default_image = default_image
 
     @overrides
-    def add_subparser(self, parser: argparse._SubParsersAction):
-        description = f'Build the docker image "{self.image}"'
+    def add_subparser(self, model: str, parser: argparse._SubParsersAction):
+        description = f'Build a Docker image for model "{model}"'
         self.parser = parser.add_parser(
-            self.image, description=description, help=description
+            model, description=description, help=description
+        )
+        self.parser.add_argument(
+            "--image-name",
+            default=self.default_image,
+            help="The name of the image to build",
         )
         self.parser.add_argument(
             "--silent",
@@ -173,7 +189,7 @@ class BuildDockerImageSubcommand(SetupSubcommand):
     @overrides
     def run(self, args):
         prepare_global_logging(silent=args.silent)
-        build_image(self.root, self.image, silent=args.silent)
+        build_image(self.root, args.image_name, silent=args.silent)
 
 
 class DockerContainer(object):
